==> ruby-dcl_1.8.1.orig.tar.gz: ruby-dcl-1.8.1/demo/grph1/sgpack/sgpk07.rb <==
#
# sgpk07.rb
#
# $Id$
#

require "numru/dcl"

include NumRu
include Math


n = 9
y = NArray.sfloat(n)

#-- graph ---
iws = (ARGV[0] || (puts ' WORKSTATION ID (I)  ? ;'; DCL::sgpwsn; gets)).to_i
DCL::sgopn iws
DCL::sgfrm

x1 = 0.1
x2 = 0.9
xc = 0.5

DCL::sgslni(1)
y = y.indgen * (-0.1) + 0.9
for i in 0..n-1
  DCL::sglnv(x1, y[i], x2, y[i])
end
DCL::sglnv(xc, 0.05, xc, 0.95)

#----------------------- SUPER/SUB SCRIPT ------------------------------
DCL::sgtxv(xc, y[0], 'SGTXV|SUP"RST_SUB"')

DCL::sgstxi(2)
DCL::sglset('LCNTL', true)                 # <-- źȥON
DCL::sgtxv(xc, y[1], 'SGTXV|SUP"RST_SUB"')

DCL::sgrset('SHIFT', 0.5)                  # <-- ե
DCL::sgrset('SMALL', 0.5)                  # <-- ź礭
DCL::sgtxv(xc, y[2], 'SGTXV|SUP"RST_SUB"')

#------------------------ FONT SELECTION -------------------------------
DCL::sgstxi(1)
DCL::sgstxs(0.05)
DCL::sgtxv(xc, y[3], 'ABCDEFG abcdefg')

DCL::sgiset('IFONT', 2)                    # <-- 줤ʥե
DCL::sgtxv(xc, y[4], 'ABCDEFG abcdefg')

DCL::sgstxi(3)
DCL::sgtxv(xc, y[5], 'ABCDEFG abcdefg')

#------------------------- GREEK LETTERS -------------------------------
greek1 = [152,153,154,155,156,157,158,159,160,161].collect{|i| DCL::csgi(i)}.join
greek2 = [130,131,135,138,141,143,145,148,150,151].collect{|i| DCL::csgi(i)}.join
DCL::sgtxv(xc, y[6], greek1)
DCL::sgtxv(xc, y[7], greek2)

#----------------------------- SYMBOLS ---------------------------------
symbol = [189,190,191,192,193,210,211,212,217,218].collect{|i| DCL::csgi(i)}.join
DCL::sgtxv(xc, y[8], symbol)

DCL::sgcls

==> ruby-dcl_1.8.2.orig.tar.gz: ruby-dcl-1.8.2/demo/grph1/sgpack/sgpk07.rb <==
#
# sgpk07.rb
#
# $Id$
#

require "numru/dcl"

include NumRu
include Math


n = 9
y = NArray.sfloat(n)

#-- graph ---
iws = (ARGV[0] || (puts ' WORKSTATION ID (I)  ? ;'; DCL::sgpwsn; gets)).to_i
DCL::sgopn iws
DCL::sgfrm

x1 = 0.1
x2 = 0.9
xc = 0.5

DCL::sgslni(1)
y = y.indgen * (-0.1) + 0.9
for i in 0..n-1
  DCL::sglnv(x1, y[i], x2, y[i])
end
DCL::sglnv(xc, 0.05, xc, 0.95)

#----------------------- SUPER/SUB SCRIPT ------------------------------
DCL::sgtxv(xc, y[0], 'SGTXV\^{SUP}RST\_{SUB}')

DCL::sgstxi(2)
DCL::sglset('LCNTL', true)                 # <-- źȥON
DCL::sgtxv(xc, y[1], 'SGTXV\^{SUP}RST\_{SUB}')

DCL::sgrset('SHIFT', 0.5)                  # <-- ե
DCL::sgrset('SMALL', 0.5)                  # <-- ź礭
DCL::swlset('LSYSFNT', true)
DCL::sgtxv(xc, y[2], 'S\o-G\o~T\u-X\o~\u-V\^{SUP}RST\_{SUB}')
DCL::swlset('LSYSFNT', false)

#------------------------ FONT SELECTION -------------------------------
DCL::sgstxi(1)
DCL::sgstxs(0.05)
DCL::sgtxv(xc, y[3], 'ABCDEFG abcdefg')

DCL::sgiset('IFONT', 2)                    # <-- 줤ʥե
DCL::sgtxv(xc, y[4], 'ABCDEFG abcdefg')

DCL::sgstxi(3)
DCL::sgtxv(xc, y[5], 'ABCDEFG abcdefg')

#------------------------- GREEK LETTERS -------------------------------
greek1 = [152,153,154,155,156,157,158,159,160,161].collect{|i| DCL::usgi(i)}.join
greek2 = [130,131,135,138,141,143,145,148,150,151].collect{|i| DCL::usgi(i)}.join
DCL::sgtxv(xc, y[6], greek1)
DCL::sgtxv(xc, y[7], greek2)

#----------------------------- SYMBOLS ---------------------------------
symbol = [189,190,191,192,193,210,211,212,217,218].collect{|i| DCL::usgi(i)}.join
DCL::sgtxv(xc, y[8], symbol)

DCL::sgcls
